<?php

namespace App;

use PDO;

class DB extends PDO
{
    private static $instance;

    public static function getInstance()
    {
        if (self::$instance === null) {
            try {
                $host = getenv('DB_HOST');
                $database = getenv('DB_DATABASE');
                $username = getenv('DB_USERNAME');
                $password = getenv('DB_PASSWORD');

                self::$instance = new DB("mysql:host={$host};dbname={$database};charset=utf8", $username, $password, [
                    PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
                    PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true,
                ]);

                self::$instance->exec('SET time_zone="+00:00"');
            } catch (\PDOException $e) {
				echo "An error has occurred with the database.\n";
                abort(500);
            }
        }

        return self::$instance;
    }

    public static function run($query, ...$params)
    {
        $query = self::getInstance()->prepare($query);
        $query->execute($params);

        try {
            return $query->fetchAll(PDO::FETCH_ASSOC);
        } catch (\PDOException $e) {
            return null;
        }
    }
}
